<?php

/*
	Note: set tab spaces to 4 for correct indentation :)
*/

$plugin_description	= gettext("Adds the possibility to share an image (generates BBCode and stuff like that)");
$plugin_author		= "Damien Courtois (Citron)";
$plugin_version		= '0.2';
$option_interface	= new share_options();
$plugin_URL			= 'http://blog.pcitron.fr/zenphoto-bbcode/';


/**
	Print a link, which, when clicked, display a ThickBox containing BBCode, for sharing
	in phpBB forums and such.
	The generated BBCode is of the form : [url=url_to_the_full_image][img]preview_img[/img][/url]
	The preview image has a size of max 800pix (based on the largest border)
*/
function print_bbcode($link_text)
{
	// get the options
	$link		= getOption('share_target_enabled');	if ($link == '')	$link = true;
	$linkTo		= getOption('share_target_link');		if ($linkTo == '')	$linkTo = 'full_image';
	$maxSize	= getOption('share_preview_max_size');	if ($maxSize == '')	$maxSize = 800;

	// thick box link
	print("<a href=\"#TB_inline?height=100&amp;width=500&amp;inlineId=bbcode\" title=\"Show BBCode\" class=\"thickbox\">\n");
	print($link_text."\n");
	print("</a>\n");

	// the bbcode div which contains a textarea with the BBCode in it
	print("<div id=\"bbcode\" style=\"display:none;\">\n");
	print("<textarea class=\"bbcode\" rows=4 cols=69 onClick=\"this.focus(); this.select();\">\n");

	// generate the [url] code
	if ($link == true)
	{
		switch ($linkTo)
		{
			case 'full_mage':	print("[url=http://gallery.pcitron.fr".getFullImageURL()."]\n");	break;
			case 'image_page':	print("[url=http://gallery.pcitron.fr".getImageLinkURL()."]\n");	break;

			// if the $linkTo option is invalid, set $link to false to avoid outputing a useless [/url]
			default: $link = false;
		}
	}

	// generate the [img] code
	print("[img]http://gallery.pcitron.fr".getCustomSizedImageMaxSpace($maxSize, $maxSize)."[/img]\n");

	// close the [url] tag
	if ($link == true)
		print("[/url]\n");

	// close textarea and bbcode div
	print("</textarea>\n");
	print("</div>\n");
}

/**
	Class handling the options of the plugin.
*/
class share_options
{
	/**
		Constructor. Set the default option values.
	*/
	function share_options()
	{
		setOptionDefault('share_preview_max_size',	800);
		setOptionDefault('share_target_enabled',	true);
		setOptionDefault('share_target_link',		'full_image');
	}

	/**
		Returns an array containing the options elements to display in the
		admin control panel.
	*/
	function getOptionsSupported()
	{
		return array(
			'Max size of the image preview'	=> array(	'key' => 'share_preview_max_size',
														'type' => 0,
														'desc' => 'Maximum size (base on the largest side) of the preview image.'),
			'Enable target link'			=> array (	'key' => 'share_target_enabled',
														'type' => 1,
														'desc' => 'If checked, a link will be generated, pointing to the full image, image page, etc.'),
			'Target link to'				=> array (	'key' => 'share_target_link',
														'type' => 5,
														'selections' => array('Full image' => 'full_mage', 'Image page' => 'image_page'),
														'desc' => 'If the targe link is enabled, select where it points to :<ul><li><b>Full image : </b>points to the full image.</li><li><b>Image page : </b></li>points to the image page.</ul>')
					);
	}

	/**
		This method handled the html generation for complex options.
		Currently not used.
	*/
	function handleOption($option, $currentValue)
	{
	}
}

?>